# Generated by Django 3.2.4 on 2022-10-24 10:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('m3_gar', '0015_alter_normativedocs_orgname'),
    ]

    operations = [
        migrations.AlterField(
            model_name='normativedocs',
            name='orgname',
            field=models.CharField(blank=True, max_length=600, null=True, verbose_name='Наименование органа создвшего нормативный документ'),
        ),
    ]
