# Generated by Django 2.2.28 on 2022-05-16 11:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('m3_gar', '0013_auto_20220513_0825'),
    ]

    operations = [
        migrations.AddField(
            model_name='addrobj',
            name='name_with_typename',
            field=models.CharField(max_length=300, null=True, verbose_name='Наименование c полным наименованием типа объекта'),
        ),
    ]
